/// <reference types="node" />
import { JobUtils } from "./JobUtils";
export interface IGetSpoolFileOption {
    /**
     * Job spool file ID.
     */
    fileId: string;
    /**
     * Job name. If it's unspecified, `*` will be used.
     */
    jobName?: string;
    /**
     * Job ID.
     */
    jobId: string;
    /**
     * Job owner. If it's unspecified, `*` will be used.
     */
    owner?: string;
}
export interface IListJobOption {
    /**
     * Job owner. If it's unspecified, `*` will be used.
     */
    owner?: string;
}
export interface IJob {
    /**
     * Job name
     */
    jobname: string;
    /**
     * Job ID
     */
    jobid: string;
    /**
     * Job owner
     */
    owner: string;
    /**
     * Job status
     */
    status: string;
    /**
     * Job class
     */
    class: string;
    /**
     * Extra information
     */
    extra?: string;
}
export interface ISpoolFile {
    /**
     * Spool file ID
     */
    id: string;
    /**
     * Job step name
     */
    stepname?: string;
    /**
     * Proc step name
     */
    procstep?: string;
    /**
     * Class
     */
    class?: string;
    /**
     * DD name
     */
    ddname?: string;
    /**
     * Bytes
     */
    byteCount?: number;
    /**
     * Contents
     */
    contents?: Buffer;
}
/**
 * Job status including rc, spool files, etc.
 */
export interface IJobStatus extends IJob {
    /**
     * Job RC value, indicating job finished with numberic value or failed with error string.
     */
    rc?: string | number;
    /**
     * Job RC value, to support zftp plugin with consistent return code format with z/OSMF.
     */
    retcode?: string;
    /**
     * Spool files.
     */
    spoolFiles?: ISpoolFile[];
}
export { JobUtils as JobUtils };
