import { ImsSession } from "../../rest";
import { IIMSApiResponse, IStartRegionParms, IUpdateProgramParms, IUpdateTransactionParms } from "../../doc";
/**
 * Start program in IMS through REST API
 * @param {AbstractSession} session - the session to connect to IMS with
 * @param {IUpdateProgramParms} parms - parameters for start program(s)
 * @returns {Promise<IIMSApiResponse>} promise that resolves to the response (XML parsed into a javascript object)
 *                          when the request is complete
 * @throws {ImperativeError} IMS program name not defined or blank
 * @throws {ImperativeError} ImsRestClient request fails
 */
export declare function startProgram(session: ImsSession, parms: IUpdateProgramParms): Promise<IIMSApiResponse>;
/**
 * Start transaction in IMS through REST API
 * @param {AbstractSession} session - the session to connect to IMS with
 * @param {IUpdateTransactionParms} parms - parameters for starting transaction(s)
 * @returns {Promise<IIMSApiResponse>} promise that resolves to the response (XML parsed into a javascript object)
 *                          when the request is complete
 * @throws {ImperativeError} IMS transaction name not defined or blank
 * @throws {ImperativeError} ImsRestClient request fails
 */
export declare function startTransaction(session: ImsSession, parms: IUpdateTransactionParms): Promise<IIMSApiResponse>;
/**
 * Start region in IMS through REST API
 * @param {AbstractSession} session - the session to connect to IMS with
 * @param {IStartRegionParms} parms - parameters for starting a region, see interface for more details
 * @returns {Promise<IIMSApiResponse>} promise that resolves to the response (XML parsed into a javascript object)
 *                          when the request is complete
 * @throws {ImperativeError} IMS member name not defined or blank
 * @throws {ImperativeError} ImsRestClient request fails
 */
export declare function startRegion(session: ImsSession, parms: IStartRegionParms): Promise<IIMSApiResponse>;
