"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@zowe/imperative");
const api_1 = require("../../../api");
const ImsBaseHandler_1 = require("../../ImsBaseHandler");
/**
 * Command handler for querying IMS regions
 * @export
 * @class RegionHandler
 * @implements {ICommandHandler}
 */
class RegionHandler extends ImsBaseHandler_1.ImsBaseHandler {
    processWithSession(params, session, profile) {
        return __awaiter(this, void 0, void 0, function* () {
            const status = {
                statusMessage: "Querying region defined to IMS",
                percentComplete: 0,
                stageName: imperative_1.TaskStage.IN_PROGRESS
            };
            params.response.progress.startBar({ task: status });
            const response = yield api_1.queryRegion(session, {
                dc: params.arguments.dc,
                region: params.arguments.region,
                route: params.arguments.route
            });
            this.checkReturnCode(response);
            params.response.format.output({
                header: true,
                output: response.data,
                format: "table"
            });
            return response;
        });
    }
}
exports.default = RegionHandler;
//# sourceMappingURL=Region.handler.js.map