"use strict";
/*
* This program and the accompanying materials are made available under the terms of the *
* Eclipse Public License v2.0 which accompanies this distribution, and is available at *
* https://www.eclipse.org/legal/epl-v20.html                                      *
*                                                                                 *
* SPDX-License-Identifier: EPL-2.0                                                *
*                                                                                 *
* Copyright Contributors to the Zowe Project.                                     *
*                                                                                 *
*/
var __awaiter = (this && this.__awaiter) || function (thisArg, _arguments, P, generator) {
    function adopt(value) { return value instanceof P ? value : new P(function (resolve) { resolve(value); }); }
    return new (P || (P = Promise))(function (resolve, reject) {
        function fulfilled(value) { try { step(generator.next(value)); } catch (e) { reject(e); } }
        function rejected(value) { try { step(generator["throw"](value)); } catch (e) { reject(e); } }
        function step(result) { result.done ? resolve(result.value) : adopt(result.value).then(fulfilled, rejected); }
        step((generator = generator.apply(thisArg, _arguments || [])).next());
    });
};
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@zowe/imperative");
const api_1 = require("../../../api");
const ImsBaseHandler_1 = require("../../ImsBaseHandler");
/**
 * Command handler for querying IMS transactions
 * @export
 * @class TransactionHandler
 * @implements {ICommandHandler}
 */
class TransactionHandler extends ImsBaseHandler_1.ImsBaseHandler {
    processWithSession(params, session, profile) {
        return __awaiter(this, void 0, void 0, function* () {
            const status = {
                statusMessage: "Querying resources from IMS",
                percentComplete: 0,
                stageName: imperative_1.TaskStage.IN_PROGRESS
            };
            params.response.progress.startBar({ task: status });
            const response = yield api_1.queryTransaction(session, {
                name: params.arguments.name,
                attributes: params.arguments.attributes,
                status: params.arguments.status,
                route: params.arguments.route,
                class: params.arguments.class,
                qcntcomp: params.arguments.queueCountOperator,
                qcntval: params.arguments.queueCountValue,
                conv: params.arguments.converationAttributes,
                fp: params.arguments.fastPathOptions,
                remote: params.arguments.remoteOptionSpecified,
                resp: params.arguments.responseModeOptionSpecified
            });
            this.checkReturnCode(response);
            params.response.format.output({
                output: response.data,
                format: "table",
                fields: params.arguments.attributes ? undefined :
                    ["tran", "mbr", "fp", "lcls", "llct", "lstt", "conv", "cmtm", "qcnt"],
                header: true
            });
            imperative_1.Logger.getAppLogger().info("Messages from the query transaction API:\n" + JSON.stringify(response.messages, null, 2));
            return response;
        });
    }
}
exports.default = TransactionHandler;
//# sourceMappingURL=Transaction.handler.js.map