"use strict";
/**
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@zowe/imperative");
const cics_for_zowe_sdk_1 = require("@zowe/cics-for-zowe-sdk");
const CicsBaseHandler_1 = require("../../CicsBaseHandler");
// Does not use the import in anticipation of some internationalization work to be done later.
const strings = require("../../-strings-/en").default.DEFINE.RESOURCES.TRANSACTION;
/**
 * Command handler for defining CICS transactions via CMCI
 * @export
 * @class TransactionHandler
 * @implements {ICommandHandler}
 */
class TransactionHandler extends CicsBaseHandler_1.CicsBaseHandler {
    async processWithSession(params, session, profile) {
        const status = {
            statusMessage: "Defining transaction to CICS",
            percentComplete: 0,
            stageName: imperative_1.TaskStage.IN_PROGRESS,
        };
        params.response.progress.startBar({ task: status });
        const response = await (0, cics_for_zowe_sdk_1.defineTransaction)(session, {
            name: params.arguments.transactionName,
            programName: params.arguments.programName,
            csdGroup: params.arguments.csdGroup,
            regionName: params.arguments.regionName || profile.regionName,
            cicsPlex: params.arguments.cicsPlex || profile.cicsPlex,
        });
        params.response.console.log(strings.MESSAGES.SUCCESS, params.arguments.transactionName);
        return response;
    }
}
exports.default = TransactionHandler;
//# sourceMappingURL=Transaction.handler.js.map