"use strict";
/**
 * This program and the accompanying materials are made available under the terms of the
 * Eclipse Public License v2.0 which accompanies this distribution, and is available at
 * https://www.eclipse.org/legal/epl-v20.html
 *
 * SPDX-License-Identifier: EPL-2.0
 *
 * Copyright Contributors to the Zowe Project.
 *
 */
Object.defineProperty(exports, "__esModule", { value: true });
const imperative_1 = require("@zowe/imperative");
const cics_for_zowe_sdk_1 = require("@zowe/cics-for-zowe-sdk");
const CicsBaseHandler_1 = require("../../CicsBaseHandler");
// Does not use the import in anticipation of some internationalization work to be done later.
const strings = require("../../-strings-/en").default.DEFINE.RESOURCES.URIMAP;
/**
 * Command handler for defining CICS URIMaps via CMCI
 * @export
 * @class UrimapClientHandler
 * @implements {ICommandHandler}
 */
class UrimapClientHandler extends CicsBaseHandler_1.CicsBaseHandler {
    async processWithSession(params, session, profile) {
        const status = {
            statusMessage: "Defining URIMAP of type Client to CICS",
            percentComplete: 0,
            stageName: imperative_1.TaskStage.IN_PROGRESS,
        };
        params.response.progress.startBar({ task: status });
        const response = await (0, cics_for_zowe_sdk_1.defineUrimapClient)(session, {
            name: params.arguments.urimapName,
            csdGroup: params.arguments.csdGroup,
            path: params.arguments.urimapPath,
            host: params.arguments.urimapHost,
            scheme: params.arguments.urimapScheme,
            description: params.arguments.description,
            enable: params.arguments.enable,
            regionName: params.arguments.regionName || profile.regionName,
            cicsPlex: params.arguments.cicsPlex || profile.cicsPlex,
            authenticate: params.arguments.authenticate,
            certificate: params.arguments.certificate,
        });
        params.response.console.log(strings.MESSAGES.SUCCESS, params.arguments.urimapName);
        return response;
    }
}
exports.default = UrimapClientHandler;
//# sourceMappingURL=UrimapClient.handler.js.map